summaryrefslogtreecommitdiff
path: root/nuttx/configs/hymini-stm32v/src/up_usbmsc.c
diff options
context:
space:
mode:
Diffstat (limited to 'nuttx/configs/hymini-stm32v/src/up_usbmsc.c')
-rw-r--r--nuttx/configs/hymini-stm32v/src/up_usbmsc.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/nuttx/configs/hymini-stm32v/src/up_usbmsc.c b/nuttx/configs/hymini-stm32v/src/up_usbmsc.c
index e7fc41907..105aed5b5 100644
--- a/nuttx/configs/hymini-stm32v/src/up_usbmsc.c
+++ b/nuttx/configs/hymini-stm32v/src/up_usbmsc.c
@@ -60,8 +60,8 @@
/* Configuration ************************************************************/
-#ifndef CONFIG_EXAMPLES_USBMSC_DEVMINOR1
-# define CONFIG_EXAMPLES_USBMSC_DEVMINOR1 0
+#ifndef CONFIG_SYSTEM_USBMSC_DEVMINOR1
+# define CONFIG_SYSTEM_USBMSC_DEVMINOR1 0
#endif
/* SLOT number(s) could depend on the board configuration */
@@ -109,7 +109,7 @@
int usbmsc_archinitialize(void)
{
/* If examples/usbmsc is built as an NSH command, then SD slot should
* already have been initialized in nsh_archinitialize() (see up_nsh.c). In
* this case, there is nothing further to be done here.
*/
@@ -136,9 +136,9 @@ int usbmsc_archinitialize(void)
message("usbmsc_archinitialize: "
"Bind SDIO to the MMC/SD driver, minor=%d\n",
- CONFIG_EXAMPLES_USBMSC_DEVMINOR1);
+ CONFIG_SYSTEM_USBMSC_DEVMINOR1);
- ret = mmcsd_slotinitialize(CONFIG_EXAMPLES_USBMSC_DEVMINOR1, sdio);
+ ret = mmcsd_slotinitialize(CONFIG_SYSTEM_USBMSC_DEVMINOR1, sdio);
if (ret != OK)
{
message("usbmsc_archinitialize: "
@@ -109,7 +109,7 @@
int usbmsc_archinitialize(void)
{
- /* If examples/usbmsc is built as an NSH command, then SD slot should
+ /* If system/usbmsc is built as an NSH command, then SD slot should
* already have been initialized in nsh_archinitialize() (see up_nsh.c). In
* this case, there is nothing further to be done here.